bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGamma.add_plate_axis
===========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGamma.add_plate_axis